-- 公共数据库键值表
Create Table If not Exists [commonDBKeyValue] (
	[ID]     	integer        	Not Null	Primary Key	AutoIncrement ,
	[DBKey]  	varchar(20)    	Not Null ,
	[DBValue]	text           	Not Null
);

-- 账户表
Create Table If not Exists [mtAccount] (
	[ID]         	integer        	Not Null	Primary Key	AutoIncrement ,
	[name]       	nvarchar(50)   	Not Null ,
	[type]       	integer        	Not Null ,
	[memo]       	nvarchar(200)  	Null ,
    [structureID]	integer        	Null ,
    [seqNO]         int             Null
);

-- 固定资产库存表
Create Table If not Exists [mtAssetsStock] (
	[ID]         	integer        	Not Null	Primary Key	AutoIncrement ,
	[assetsID]   	integer        	Null ,
	[batchID]    	integer        	Null ,
	[stockDate]  	datetime       	Null ,
	[transID]    	integer        	Null ,
	[months]     	integer        	Null ,
	[quantity]   	integer        	Null ,
	[price]      	double         	Null ,
	[stockCount] 	integer        	Null ,
	[batchMonths]	integer        	Null ,
	[batchAmount]	double         	Null
);

-- 分类
Create Table If not Exists [mtCategory] (
	[ID]      	integer        	Not Null	Primary Key	AutoIncrement ,
	[name]    	nvarchar(50)   	Not Null ,
	[type]    	integer        	Null ,
	[isSystem]	int            	Null	 default(0) ,
	[memo]    	nvarchar(200)  	Null ,
    [tag]       int            	Null	 default(0) ,
    [seqNO]     int             Null  
);

-- 固定资产
Create Table If not Exists [mtFixedAssets] (
	[ID]  	integer        	Not Null	Primary Key	AutoIncrement ,
	[name]	nvarchar(50)   	Null ,
    [py]    varchar(100)    Null
);

-- 货品
Create Table If not Exists [mtGoods] (
	[ID]      	integer        	Not Null	Primary Key	AutoIncrement ,
	[name]    	nvarchar(50)   	Not Null ,
	[version] 	varchar(20)    	Null ,
	[unit]    	nvarchar(10)   	Null ,
	[price]   	double         	Null ,
	[discount]	float          	Null ,
    [py]        varchar(100)    Null
);

-- 收支交易
Create Table If not Exists [mtIAETrans] (
	[ID]               	integer        	Not Null	Primary Key	AutoIncrement ,
	[transID]          	integer        	Null ,
	[categoryID]       	integer        	Null ,
	[structureID]      	integer        	Null ,
	[amortizeNumber]   	integer        	Null ,
	[amortizeFrequency]	integer        	Null ,
	[shouldAmount]     	double         	Null ,
	[amount]           	double         	Null
);

-- 分录
Create Table If not Exists [mtJournalRecord] (
	[transID]  	integer        	Not Null ,
	[ID]       	integer        	Not Null	Primary Key ,
	[subjectID]	integer        	Null ,
	[amount]   	double         	Null ,
	[transDate]	datetime       	Null ,
	[objType]  	integer        	Null 	 default(0) ,
	[objID]    	integer        	Null	 default(0) 
);

-- 进销存订单
Create Table If not Exists [mtOrderInfo] (
	[ID]          	integer        	Not Null	Primary Key	AutoIncrement ,
	[transID]     	integer        	Null ,
	[orderKey]    	varchar(50)    	Null ,
	[targetID]    	integer        	Null ,
	[shouldAmount]	double         	Null ,
	[amount]      	double         	Null ,
	[orderDate]   	datetime       	Null
);

-- 货品库存
Create Table If not Exists [mtStock] (
	[ID]         	integer        	Not Null	Primary Key	AutoIncrement ,
	[goodsID]    	integer        	Null ,
	[stockDate]  	datetime       	Null ,
	[transID]    	integer        	Null ,
	[quantity]   	integer        	Null ,
	[price]      	double         	Null ,
    [discount]      double         	Null     default(1) ,
	[changeValue]	integer        	Null	 default(0) ,
	[costs]      	double         	Null	 default(0) 
);

-- 个人单位（往来）（对方）
Create Table If not Exists [mtStructure] (
	[ID]     	integer        	Not Null	Primary Key	AutoIncrement ,
	[name]   	nvarchar(50)   	Not Null ,
	[address]	nvarchar(100)  	Null ,
	[linkman]	nvarchar(50)   	Null ,
	[phone]  	varchar(50)    	Null ,
	[fax]    	varchar(50)    	Null ,
	[bank]   	nvarchar(50)   	Null ,
	[cardNO] 	varchar(50)    	Null ,
	[memo]   	nvarchar(200)  	Null ,
    [py]        varchar(100)    Null
);

-- 价签关系表
Create Table If not Exists [mtTagForPrice] (
	[ID]        	integer        	Not Null	Primary Key	AutoIncrement ,
	[transID]   	integer        	Null ,
	[tagGoodsID]	integer        	Null ,
	[price]     	double         	Null ,
	[quantity]  	integer        	Null
);

-- 价签商品
Create Table If not Exists [mtTagGoods] (
	[ID]  	integer        	Not Null	Primary Key	AutoIncrement ,
	[name]	nvarchar(50)   	Null ,
	[unit]	nvarchar(10)   	Null ,
    [py]    varchar         Null
);

-- 交易
Create Table If not Exists [mtTransaction] (
	[ID]        	integer        	Not Null	Primary Key	AutoIncrement ,
	[activityID]	integer        	Null ,
	[transDate] 	datetime       	Null ,
	[amount]    	double         	Null ,
	[memo]      	nvarchar(200)  	Null
);

-- 库存周转天数
Create Table If not Exists [mtCircleStat] (
	[yearMonth] 	integer        	Not Null ,
	[goodsID]   	integer        	Not Null ,
	[circleDays]	integer        	Null 	 default(0),
	PRIMARY KEY (yearMonth ,goodsID)
);

-- 客户借贷余额
Create Table If not Exists [mtCustomEndBalance] (
	[customerID]   	integer        	Not Null ,
	[type]         	integer     	Not Null ,
	[endingBalance]	double         	Null	 default(0),
    PRIMARY KEY (customerID ,type)
);

-- 日表
Create Table If not Exists [mtDailyStat] (
	[dtNum]      	integer        	Not Null	Primary Key ,
	[income]     	double         	Null	 default(0) ,
	[gross]      	double         	Null	 default(0) ,
	[stock]      	double         	Null	 default(0) ,
	[receivables]	double         	Null	 default(0)
);

-- 月表
Create Table If not Exists [mtMonthStat] (
	[yearMonth]	integer        	Not Null	Primary Key ,
	[income]   	double         	Null	 default(0) ,
	[fee]      	double         	Null	 default(0) ,
	[gross]    	double         	Null	 default(0) ,
	[profit]   	double         	Null	 default(0)
);

-- 周表
Create Table If not Exists [mtWeekStat] (
	[monday]	integer        	Not Null ,
	[sunday]	integer        	Not Null ,
	[income]	double         	Null	 default(0),
	PRIMARY KEY (monday ,sunday)
);

-- 记录榜表
Create Table If not Exists [mtRecordList] (
	[dtNum]	integer        	Not Null ,
	[type]	integer        	Not Null ,
	[content]	text         	Null	 default(''),
	PRIMARY KEY (dtNum ,type)
);